#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_intent_count_info
short_description: Information module for Network Devices Intent Count
description:
  - Get all Network Devices Intent Count.
  - API to fetch the count of network devices using basic filters.
  - Use the `/dna/intent/api/v1/networkDevices/query/count` API if you need advanced filtering.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id query parameter. Network device Id.
    type: str
  managementAddress:
    description:
      - ManagementAddress query parameter. Management address of the network device.
    type: str
  serialNumber:
    description:
      - SerialNumber query parameter. Serial number of the network device.
    type: str
  family:
    description:
      - Family query parameter. Product family of the network device. For example, Switches, Routers, etc.
    type: str
  stackDevice:
    description:
      - StackDevice query parameter. Flag indicating if the device is a stack device.
    type: str
  role:
    description:
      - >
        Role query parameter. Role assigned to the network device. Available values BORDER_ROUTER, CORE,
        DISTRIBUTION, ACCESS, UNKNOWN.
    type: str
  status:
    description:
      - >
        Status query parameter. Inventory related status of the network device. Available values MANAGED,
        SYNC_NOT_STARTED, SYNC_INIT_FAILED, SYNC_PRECHECK_FAILED, SYNC_IN_PROGRESS, SYNC_INTERNAL_ERROR,
        SYNC_DISABLED, DELETING_DEVICE, UNDER_MAINTENANCE, QUARANTINED, UNASSOCIATED, UNREACHABLE, UNKNOWN.
        Refer features for more details.
    type: str
  reachabilityStatus:
    description:
      - >
        ReachabilityStatus query parameter. Reachability status of the network device. Available values
        REACHABLE, ONLY_PING_REACHABLE, UNREACHABLE, UNKNOWN. Refer features for more details.
    type: str
  managementState:
    description:
      - >
        ManagementState query parameter. The status of the network device's manageability. Available values
        MANAGED, UNDER_MAINTENANCE, NEVER_MANAGED. Refer features for more details.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CountTheNumberOfNetworkDevices
    description: Complete reference of the CountTheNumberOfNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!count-the-number-of-network-devices
notes:
  - SDK Method used are
    devices.Devices.count_the_number_of_network_devices,
  - Paths used are
    get /dna/intent/api/v1/networkDevices/count,
"""

EXAMPLES = r"""
---
- name: Get all Network Devices Intent Count
  cisco.dnac.network_devices_intent_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    managementAddress: string
    serialNumber: string
    family: string
    stackDevice: string
    role: string
    status: string
    reachabilityStatus: string
    managementState: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: compliance_policys_rules_conditions
short_description: Resource module for Compliance Policys Rules Conditions
description:
  - Manage operations create, update and delete of the resource Compliance Policys Rules Conditions.
  - This API operation creates a new condition within the specified compliance policy and rule.
  - Deletes a specific condition within the specified compliance policy and rule.
  - Updates an existing compliance condition within the specified compliance policy and rule.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  action:
    description: Compliance Policys Rules Conditions's action.
    suboptions:
      doesNotMatchAction:
        description: Action to take when the condition does not match. The choice of action influences whether a violation
          is logged and whether further conditions are evaluated. For detailed enum descriptions, refer to the `Features`
          tab.
        type: str
      doesNotMatchViolationMessage:
        description: Specify the custom violation message to be used to report violations when the condition does not match
          and raises violation. This field is applicable and required when `doesNotMatchViolationMessageType` is `CUSTOM_MESSAGE`.
          Custom variables and automatically generated regular expression group variables can both be used in this field,
          similar to how they are used in the `value` field.
        type: str
      doesNotMatchViolationMessageType:
        description: The type of message to display when the condition does not match and results in a violation. This provides
          context about the violation. This field is applicable and required when `doesNotMatchAction` is either `RAISE_VIOLATION_AND_CONTINUE`
          or `RAISE_VIOLATION_AND_STOP`. For detailed enum descriptions, refer to the `Features` tab.
        type: str
      doesNotMatchViolationSeverity:
        description: The severity level of the violation when the condition does not match. This field is applicable and required
          when `doesNotMatchAction` is either `RAISE_VIOLATION_AND_CONTINUE` or `RAISE_VIOLATION_AND_STOP`.
        type: str
      matchAction:
        description: Action to take when the condition matches. The choice of action influences whether a violation is logged
          and whether further conditions are evaluated. For detailed enum descriptions, refer to the `Features` tab.
        type: str
      matchViolationMessage:
        description: Specify the custom violation message to be used to report violations when the condition matches and raises
          violation. This field is applicable and required when `matchViolationMessageType` is `CUSTOM_MESSAGE`. Custom variables
          and automatically generated regular expression group variables can both be used in this field, similar to how they
          are used in the `value` field.
        type: str
      matchViolationMessageType:
        description: The type of message to display when the condition matches and results in a violation. This provides context
          about the violation. This field is applicable and required when `matchAction` is either `RAISE_VIOLATION_AND_CONTINUE`
          or `RAISE_VIOLATION_AND_STOP`. For detailed enum descriptions, refer to the `Features` tab.
        type: str
      matchViolationSeverity:
        description: The severity level of the violation when the condition matches. This field is applicable and required
          when `matchAction` is either `RAISE_VIOLATION_AND_CONTINUE` or `RAISE_VIOLATION_AND_STOP`.
        type: str
    type: dict
  blockEndExpression:
    description: The regular expression defining the end of a block. If not specified, block parsing will continue until new
      section starts in the configuration. This is applicable only when `parseAsBlocks` is set. This is an optional field.
      The value, when provided, must be a valid regular expression.
    type: str
  blockStartExpression:
    description: The regular expression defining the start of a block. This is used to identify the beginning of relevant
      configuration sections. This is applicable and required only when `parseAsBlocks` is set. The value must be a valid
      regular expression.
    type: str
  blockViolationCriteria:
    description: Criteria determining when a violation is raised based on block evaluation results. This allows for flexible
      compliance checks depending on whether a single failure or all failures should trigger a violation. For detailed enum
      descriptions, refer to the `Features` tab.
    type: str
  deviceProperty:
    description: The specific device property to consider as source for the condition. For detailed enum descriptions, refer
      to the `Features` tab.
    type: str
  id:
    description: Id path parameter. The `id` of the condition.
    type: str
  operator:
    description: The operation used to evaluate the condition. String, regular expression, and expressions required for the
      operator to work are provided in `value` attribute. For detailed enum descriptions, refer to the `Features` tab.
    type: str
  parseAsBlocks:
    description: An optional param that indicates whether to parse the configuration as discrete blocks for evaluation. Useful
      for conditions that apply to specific sections of a configuration file. This is applicable for all condition scopes
      except `DEVICE_PROPERTIES`. When scope is `PREVIOUSLY_MATCHED_BLOCKS`, this helps extract sub-blocks or portion of the
      blocks. When this is set, `blockStartExpression` must be provided. Optionally, `blockEndExpression` can be provided
      to customise blocks further.
    type: bool
  policyId:
    description: PolicyId path parameter. The `id` of the compliance policy.
    type: str
  regexViolationCriteria:
    description: Criteria determining when a violation is raised based on regular expression evaluation results. This allows
      for flexible compliance checks depending on whether a single failure or all failures should trigger a violation. For
      detailed enum descriptions, refer to the `Features` tab.
    type: str
  ruleId:
    description: RuleId path parameter. The `id` of the rule within the compliance policy.
    type: str
  scope:
    description: The source of data for the evaluation of the condition. For detailed enum descriptions, refer to the `Features`
      tab.
    type: str
  showCommand:
    description: "The command executed on the device to retrieve output for evaluation. Pattern ^((S|s)(H|h)(O|o)(W|w))\\s+.+$
      — The string must start with `show` (case-insensitive), followed by at least one space, and then any sequence of characters.
      For detailed information on using `show` command, refer to the `Features` tab."
    type: str
  value:
    description: The value or pattern used in the condition evaluation. Custom variables and automatically generated regular
      expression group variables can both be used in this field. For detailed information on using variables, refer to the
      `Features` tab.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance CreateANewCondition
    description: Complete reference of the CreateANewCondition API.
    link: https://developer.cisco.com/docs/dna-center/#!create-a-new-condition
  - name: Cisco DNA Center documentation for Compliance DeleteASpecificCondition
    description: Complete reference of the DeleteASpecificCondition API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-specific-condition
  - name: Cisco DNA Center documentation for Compliance UpdateAnExistingCondition
    description: Complete reference of the UpdateAnExistingCondition API.
    link: https://developer.cisco.com/docs/dna-center/#!update-an-existing-condition
notes:
  - SDK Method used are
    compliance.Compliance.create_a_new_condition,
    compliance.Compliance.delete_a_specific_condition,
    compliance.Compliance.update_an_existing_condition,
  - Paths used are
    post /dna/intent/api/v1/compliancePolicys/{policyId}/rules/{ruleId}/conditions,
    delete /dna/intent/api/v1/compliancePolicys/{policyId}/rules/{ruleId}/conditions/{id},
    put /dna/intent/api/v1/compliancePolicys/{policyId}/rules/{ruleId}/conditions/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.compliance_policys_rules_conditions:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    action:
      doesNotMatchAction: string
      doesNotMatchViolationMessage: string
      doesNotMatchViolationMessageType: string
      doesNotMatchViolationSeverity: string
      matchAction: string
      matchViolationMessage: string
      matchViolationMessageType: string
      matchViolationSeverity: string
    blockEndExpression: string
    blockStartExpression: string
    blockViolationCriteria: string
    deviceProperty: string
    operator: string
    parseAsBlocks: true
    policyId: string
    regexViolationCriteria: string
    ruleId: string
    scope: string
    showCommand: string
    value: string
- name: Delete by id
  cisco.dnac.compliance_policys_rules_conditions:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
    policyId: string
    ruleId: string
- name: Update by id
  cisco.dnac.compliance_policys_rules_conditions:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    action:
      doesNotMatchAction: string
      doesNotMatchViolationMessage: string
      doesNotMatchViolationMessageType: string
      doesNotMatchViolationSeverity: string
      matchAction: string
      matchViolationMessage: string
      matchViolationMessageType: string
      matchViolationSeverity: string
    blockEndExpression: string
    blockStartExpression: string
    blockViolationCriteria: string
    deviceProperty: string
    id: string
    operator: string
    parseAsBlocks: true
    policyId: string
    regexViolationCriteria: string
    ruleId: string
    scope: string
    showCommand: string
    value: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_network_device_id_config_features_intended_device_deployments_info
short_description: Information module for Wired Network Devices Network Device Id Config Features Intended Device Deployments
description:
  - Get all Wired Network Devices Network Device Id Config Features Intended Device Deployments.
  - The API returns device deployment status based on filter criteria.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - >
        NetworkDeviceId path parameter. Network device ID of the wired device to provision. The API
        /intent/api/v1/network-device can be used to get the network device ID.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wired GetDeviceDeploymentStatusConnectivity
    description: Complete reference of the GetDeviceDeploymentStatusConnectivity API.
    link: https://developer.cisco.com/docs/dna-center/#!get-device-deployment-status-connectivity
notes:
  - SDK Method used are
    wired.Wired.get_device_deployment_status_connectivity,
  - Paths used are
    get /dna/intent/api/v1/wired/networkDevices/{networkDeviceId}/configFeatures/intended/deviceDeployments,
"""

EXAMPLES = r"""
---
- name: Get all Wired Network Devices Network Device Id Config Features Intended Device Deployments
  cisco.dnac.wired_network_devices_network_device_id_config_features_intended_device_deployments_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "activityId": "string",
          "configGroupName": "string",
          "configGroupVersion": 0,
          "status": "string",
          "networkDeviceId": "string",
          "createTime": 0,
          "lastUpdateTime": 0,
          "startTime": 0,
          "endTime": 0,
          "error": {
            "message": "string",
            "remedy": "string"
          }
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_kpi_summaries_count_info
short_description: Information module for Site Kpi Summaries Count
description:
  - Get all Site Kpi Summaries Count. - > Returns the total number of site analytics records available for for given set of
    query parameters. For detailed information about the usage of the API, please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org- SiteKpiSummaries-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        `Global/AreaName/BuildingName/FloorName`) This field supports wildcard asterisk (`*`) character search
        support. E.g. `*/San*, */San, /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports wildcard asterisk (`*`) character
        search support. E.g. `*uuid*, *uuid, uuid*` Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site. (Ex. `flooruuid`) Examples `?siteId=id1` (single id
        requested) `?siteId=id1&siteId=id2&siteId=id3` (multiple ids requested).
    type: str
  siteType:
    description:
      - >
        SiteType query parameter. The type of the site. A site can be an area, building, or floor. Default when
        not provided will be `floor,building,area` Examples `?siteType=area` (single siteType requested)
        `?siteType=area&siteType=building&siteType=floor` (multiple siteTypes requested).
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfQueryParameters
    description: Complete reference of the GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfQueryParameters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-total-number-of-site-analytics-records-available-for-for-given-set-of-query-parameters
notes:
  - SDK Method used are
    sites.Sites.get_the_total_number_of_site_analytics_records_available_for_for_given_set_of_query_parameters,
  - Paths used are
    get /dna/data/api/v1/siteKpiSummaries/count,
"""

EXAMPLES = r"""
---
- name: Get all Site Kpi Summaries Count
  cisco.dnac.site_kpi_summaries_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    siteHierarchy: string
    siteHierarchyId: string
    siteId: string
    siteType: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_kpi_summaries_query_count
short_description: Resource module for Site Kpi Summaries Query Count
description:
  - Manage operation create of the resource Site Kpi Summaries Query Count. - > Returns the total number of site analytics
    records available for for given set of filters. For detailed information about the usage of the API, please refer to the
    Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    SiteKpiSummaries-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  endTime:
    description: End Time.
    type: int
  filters:
    description: Site Kpi Summaries Query Count's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfFilters
    description: Complete reference of the GetTheTotalNumberOfSiteAnalyticsRecordsAvailableForForGivenSetOfFilters API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-total-number-of-site-analytics-records-available-for-for-given-set-of-filters
notes:
  - SDK Method used are
    sites.Sites.get_the_total_number_of_site_analytics_records_available_for_for_given_set_of_filters,
  - Paths used are
    post /dna/data/api/v1/siteKpiSummaries/query/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.site_kpi_summaries_query_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    endTime: 0
    filters:
      - key: string
        operator: string
        value: string
    headers: '{{my_headers | from_json}}'
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_applications_count_info
short_description: Information module for Network Applications Count
description:
  - Get all Network Applications Count. - > Retrieves the number of network applications by applying basic filtering. If startTime
    and endTime are not provided, the API defaults to the last 24 hours. `siteId` is mandatory. `siteId` must be a site UUID
    of a building. For detailed information about the usage of the API, please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst-center-api- specs/blob/main/Assurance/CE_Cat_Center_Org-NetworkApplications-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  siteId:
    description:
      - >
        SiteId query parameter. The site UUID without the top level hierarchy. `siteId` is mandatory. `siteId`
        must be a site UUID of a building. (Ex."buildingUuid") Examples `siteId=buildingUuid` (single siteId
        requested) `siteId=buildingUuid1&siteId=buildingUuid2` (multiple siteId requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. In the context of a network application, SSID refers to the name of the wireless
        network to which the client connects. Examples `ssid=Alpha` (single ssid requested)
        `ssid=Alpha&ssid=Guest` (multiple ssid requested).
    type: str
  applicationName:
    description:
      - >
        ApplicationName query parameter. Name of the application for which the experience data is intended.
        Examples `applicationName=webex` (single applicationName requested)
        `applicationName=webex&applicationName=teams` (multiple applicationName requested).
    type: str
  businessRelevance:
    description:
      - >
        BusinessRelevance query parameter. The application can be chosen to be categorized as business-relevant,
        irrelevant, or default (neutral). By doing so, the assurance application prioritizes the monitoring and
        analysis of business-relevant data, ensuring critical insights are captured. Applications marked as
        irrelevant or default are selectively excluded from certain data sets, streamlining focus on what's most
        important for business outcomes.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Applications RetrievesTheTotalCountOfNetworkApplicationsByApplyingBasicFiltering
    description: Complete reference of the RetrievesTheTotalCountOfNetworkApplicationsByApplyingBasicFiltering API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-total-count-of-network-applications-by-applying-basic-filtering
notes:
  - SDK Method used are
    applications.Applications.retrieves_the_total_count_of_network_applications_by_applying_basic_filtering,
  - Paths used are
    get /dna/data/api/v1/networkApplications/count,
"""

EXAMPLES = r"""
---
- name: Get all Network Applications Count
  cisco.dnac.network_applications_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    siteId: string
    ssid: string
    applicationName: string
    businessRelevance: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_export_credentials_create
short_description: Resource module for Network Devices Export Credentials Create
description:
  - Manage operation create of the resource Network Devices Export Credentials Create. - > Exports device credentials of all
    network devices in the inventory to an encrypted CSV file. To export credentials for selected devices only, provide the
    networkDeviceIds parameter in the request body. The exported file will be in zip format encrypted using the password provided
    in the request body. The ZIP file will contain a CSV file with the credentials of the selected network devices. If networkDeviceIds
    is not provided, then the credentials of all the network devices will be exported. Credentials for access points and Meraki
    devices cannot be exported. The response contains a task ID. Use the /dna/intent/api/v1/tasks/{taskId} API to check the
    status of the task. The task will be completed when the file is ready for download. The download URL will be available
    in the resultLocation attribute of the task API response.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  exportSshKey:
    description: Flag to export the SSH key. If not provided, the SSH key will not be exported.
    type: bool
  networkDeviceIds:
    description: List of network device IDs to export the credentials for. If not provided, all devices will be exported.
    elements: str
    type: list
  password:
    description: Password to encrypt the CSV file. A password must contain, at minimum 8 characters, one lowercase letter,
      one uppercase letter, one number, one special character (-=;,./~!@#$%^&*()_+{}| ?). The password cannot contain spaces
      or the characters < >.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices ExportsTheCredentialsOfNetworkDevices
    description: Complete reference of the ExportsTheCredentialsOfNetworkDevices API.
    link: https://developer.cisco.com/docs/dna-center/#!exports-the-credentials-of-network-devices
notes:
  - SDK Method used are
    devices.Devices.exports_the_credentials_of_network_devices,
  - Paths used are
    post /dna/intent/api/v1/networkDevices/exportCredentials,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_devices_export_credentials_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    exportSshKey: true
    networkDeviceIds:
      - string
    password: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: compliance_policys_rules_info
short_description: Information module for Compliance Policys Rules
description:
  - Get all Compliance Policys Rules.
  - Get Compliance Policys Rules by id.
  - Retrieves the details of a rule under the specified compliance policy.
  - Retrieves the list of rules under the specified compliance policy.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  policyId:
    description:
      - PolicyId path parameter. The `id` of the compliance policy.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. Default is 500 if not specified.
        Maximum allowed limit is 500.
    type: int
  id:
    description:
      - Id path parameter. The `id` of the rule within the compliance policy.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Compliance RetrieveASpecificRule
    description: Complete reference of the RetrieveASpecificRule API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-a-specific-rule
  - name: Cisco DNA Center documentation for Compliance RetrieveTheRules
    description: Complete reference of the RetrieveTheRules API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-the-rules
notes:
  - SDK Method used are
    compliance.Compliance.retrieve_a_specific_rule,
    compliance.Compliance.retrieve_the_rules,
  - Paths used are
    get /dna/intent/api/v1/compliancePolicys/{policyId}/rules,
    get /dna/intent/api/v1/compliancePolicys/{policyId}/rules/{id},
"""

EXAMPLES = r"""
---
- name: Get all Compliance Policys Rules
  cisco.dnac.compliance_policys_rules_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
    policyId: string
  register: result
- name: Get Compliance Policys Rules by id
  cisco.dnac.compliance_policys_rules_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    policyId: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "name": "string",
        "description": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: authentication_policy_servers
short_description: Resource module for Authentication Policy Servers
description:
  - Manage operations create, update and delete of the resource Authentication Policy Servers. - > API to add AAA/ISE server
    access configuration. Protocol can be configured as either RADIUS OR TACACS OR RADIUS_TACACS. If configuring Cisco ISE
    server, after configuration, use 'Cisco ISE Server Integration Status' Intent API to check the integration status. Based
    on integration status, if require use 'Accept Cisco ISE Server Certificate for Cisco ISE Server Integration' Intent API
    to accept the Cisco ISE certificate for Cisco ISE server integration, then use again 'Cisco ISE Server Integration Status'
    Intent API to check the integration status.
  - API to delete AAA/ISE server access configuration. - > API to edit AAA/ISE server access configuration. After edit, use
    'Cisco ISE Server Integration Status' Intent API to check the integration status.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  accountingPort:
    description: Accounting port of RADIUS server. It is required for RADIUS server. The range is from 1 to 65535. E.g. 1813.
    type: int
  authenticationPort:
    description: Authentication port of RADIUS server. It is required for RADIUS server. The range is from 1 to 65535. E.g.
      1812.
    type: int
  ciscoIseDtos:
    description: Authentication Policy Servers's ciscoIseDtos.
    elements: dict
    suboptions:
      description:
        description: Description about the Cisco ISE server.
        type: str
      fqdn:
        description: Fully-qualified domain name of the Cisco ISE server. E.g. Xi-62.my.com.
        type: str
      ipAddress:
        description: IP Address of the Cisco ISE Server.
        type: str
      password:
        description: Password of the Cisco ISE server.
        type: str
      sshkey:
        description: SSH key of the Cisco ISE server.
        type: str
      subscriberName:
        description: Subscriber name of the Cisco ISE server. E.g. Pxgrid_client_1662589467.
        type: str
      userName:
        description: User name of the Cisco ISE server.
        type: str
    type: list
  encryptionKey:
    description: Encryption key used to encrypt shared secret.
    type: str
  encryptionScheme:
    description: Type of encryption scheme for additional security.
    type: str
  externalCiscoIseIpAddrDtos:
    description: Authentication Policy Servers's externalCiscoIseIpAddrDtos.
    elements: dict
    suboptions:
      externalCiscoIseIpAddresses:
        description: Authentication Policy Servers's externalCiscoIseIpAddresses.
        elements: dict
        suboptions:
          externalIpAddress:
            description: External IP Address.
            type: str
        type: list
      type:
        description: Type.
        type: str
    type: list
  id:
    description: Id path parameter. Authentication and Policy Server Identifier. Use 'Get Authentication and Policy Servers'
      intent API to find the identifier.
    type: str
  ipAddress:
    description: IP address of authentication and policy server.
    type: str
  isIseEnabled:
    description: Value true for Cisco ISE Server. Default value is false.
    type: bool
  messageKey:
    description: Message key used to encrypt shared secret.
    type: str
  port:
    description: Port of TACACS server. It is required for TACACS server. The range is from 1 to 65535.
    type: int
  protocol:
    description: Type of protocol for authentication and policy server. If already saved with RADIUS, can update to RADIUS_TACACS.
      If already saved with TACACS, can update to RADIUS_TACACS.
    type: str
  pxgridEnabled:
    description: Value true for enable, false for disable. Default value is true.
    type: bool
  retries:
    description: Number of communication retries between devices and authentication and policy server. The range is from 1
      to 3.
    type: str
  role:
    description: Role of authentication and policy server. E.g. Primary, secondary.
    type: str
  sharedSecret:
    description: Shared secret between devices and authentication and policy server.
    type: str
  timeoutSeconds:
    description: Number of seconds before timing out between devices and authentication and policy server. The range is from
      2 to 20.
    type: str
  useDnacCertForPxgrid:
    description: Value true to use Catalyst Center certificate for Pxgrid. Default value is false.
    type: bool
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for System Settings AddAuthenticationAndPolicyServerAccessConfiguration
    description: Complete reference of the AddAuthenticationAndPolicyServerAccessConfiguration API.
    link: https://developer.cisco.com/docs/dna-center/#!add-authentication-and-policy-server-access-configuration
  - name: Cisco DNA Center documentation for System Settings DeleteAuthenticationAndPolicyServerAccessConfiguration
    description: Complete reference of the DeleteAuthenticationAndPolicyServerAccessConfiguration API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-authentication-and-policy-server-access-configuration
  - name: Cisco DNA Center documentation for System Settings EditAuthenticationAndPolicyServerAccessConfiguration
    description: Complete reference of the EditAuthenticationAndPolicyServerAccessConfiguration API.
    link: https://developer.cisco.com/docs/dna-center/#!edit-authentication-and-policy-server-access-configuration
notes:
  - SDK Method used are
    system_settings.SystemSettings.add_authentication_and_policy_server_access_configuration,
    system_settings.SystemSettings.delete_authentication_and_policy_server_access_configuration,
    system_settings.SystemSettings.edit_authentication_and_policy_server_access_configuration,
  - Paths used are
    post /dna/intent/api/v1/authentication-policy-servers,
    delete /dna/intent/api/v1/authentication-policy-servers/{id},
    put /dna/intent/api/v1/authentication-policy-servers/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.authentication_policy_servers:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    accountingPort: 0
    authenticationPort: 0
    ciscoIseDtos:
      - description: string
        fqdn: string
        ipAddress: string
        password: string
        sshkey: string
        subscriberName: string
        userName: string
    encryptionKey: string
    encryptionScheme: string
    externalCiscoIseIpAddrDtos:
      - externalCiscoIseIpAddresses:
          - externalIpAddress: string
        type: string
    ipAddress: string
    isIseEnabled: true
    messageKey: string
    port: 0
    protocol: string
    pxgridEnabled: true
    retries: string
    role: string
    sharedSecret: string
    timeoutSeconds: string
    useDnacCertForPxgrid: true
- name: Delete by id
  cisco.dnac.authentication_policy_servers:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.authentication_policy_servers:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    accountingPort: 0
    authenticationPort: 0
    ciscoIseDtos:
      - description: string
        fqdn: string
        ipAddress: string
        password: string
        sshkey: string
        subscriberName: string
        userName: string
    externalCiscoIseIpAddrDtos:
      - externalCiscoIseIpAddresses:
          - externalIpAddress: string
        type: string
    id: string
    port: 0
    protocol: string
    pxgridEnabled: true
    retries: string
    timeoutSeconds: string
    useDnacCertForPxgrid: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_id_config_features_intended_layer2_feature_info
short_description: Information module for Wired Network Devices Id Config Features Intended Layer2 Feature
description:
  - Get Wired Network Devices Id Config Features Intended Layer2 Feature by id.
  - This API returns the configurations for an intended layer 2 feature on a wired device.
  - Even after the intended configurations are deployed using the deploy API,
    they continue to be a part of the intended features on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Network device ID of the wired device to configure.
    type: str
  feature:
    description:
      - Feature path parameter. The name of the feature to be retrieved.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wired GetConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
    description: Complete reference of the GetConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!get-configurations-for-an-intended-layer-2-feature-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.get_configurations_for_an_intended_layer2_feature_on_a_wired_device,
  - Paths used are
    get /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
"""

EXAMPLES = r"""
---
- name: Get Wired Network Devices Id Config Features Intended Layer2 Feature by id
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    feature: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "cdpGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "timer": 0,
            "isCdpEnabled": true,
            "isLogDuplexMismatchEnabled": true,
            "isAdvertiseV2Enabled": true,
            "holdTime": 0
          }
        ]
      },
      "cdpInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "isCdpEnabled": true,
            "isLogDuplexMismatchEnabled": true
          }
        ]
      },
      "dhcpSnoopingInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "isTrustedInterface": true,
            "messageRateLimit": 0
          }
        ]
      },
      "dhcpSnoopingGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "isDhcpSnoopingEnabled": true,
            "databaseAgent": {
              "configType": "string",
              "agentUrl": "string",
              "timeout": 0,
              "writeDelay": 0
            },
            "isGleaningEnabled": true,
            "proxyBridgeVlans": "string",
            "dhcpSnoopingVlans": "string"
          }
        ]
      },
      "dot1xInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "authenticationOrder": {
              "configType": "string",
              "items": [
                "string"
              ]
            }
          }
        ]
      },
      "dot1xGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "authenticationConfigMode": "string",
            "isDot1xEnabled": true
          }
        ]
      },
      "lldpGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "timer": 0,
            "isLldpEnabled": true,
            "reinitializationDelay": 0,
            "holdTime": 0
          }
        ]
      },
      "lldpInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "adminStatus": "string"
          }
        ]
      },
      "mabInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "isMabEnabled": true
          }
        ]
      },
      "mldSnoopingGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "isMldSnoopingEnabled": true,
            "isSuppressListenerMessagesEnabled": true,
            "isQuerierEnabled": true,
            "querierAddress": "string",
            "querierQueryInterval": 0,
            "querierVersion": "string",
            "mldSnoopingVlanSettings": {
              "configType": "string",
              "items": [
                {
                  "configType": "string",
                  "vlanId": 0,
                  "isMldSnoopingEnabled": true,
                  "isImmediateLeaveEnabled": true,
                  "isQuerierEnabled": true,
                  "querierAddress": "string",
                  "querierQueryInterval": 0,
                  "querierVersion": "string",
                  "mldSnoopingVlanMrouters": {
                    "configType": "string",
                    "items": [
                      {
                        "configType": "string",
                        "interfaceName": "string"
                      }
                    ]
                  }
                }
              ]
            }
          }
        ]
      },
      "igmpSnoopingGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "isIgmpSnoopingEnabled": true,
            "isQuerierEnabled": true,
            "querierAddress": "string",
            "querierQueryInterval": 0,
            "querierVersion": "string",
            "igmpSnoopingVlanSettings": {
              "configType": "string",
              "items": [
                {
                  "configType": "string",
                  "vlanId": 0,
                  "isIgmpSnoopingEnabled": true,
                  "isImmediateLeaveEnabled": true,
                  "isQuerierEnabled": true,
                  "querierAddress": "string",
                  "querierQueryInterval": 0,
                  "querierVersion": "string",
                  "igmpSnoopingVlanMrouters": {
                    "configType": "string",
                    "items": [
                      {
                        "configType": "string",
                        "interfaceName": "string"
                      }
                    ]
                  }
                }
              ]
            }
          }
        ]
      },
      "stpGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "stpMode": "string",
            "isBackboneFastEnabled": true,
            "isEtherChannelGuardEnabled": true,
            "isExtendedSystemIdEnabled": true,
            "isLoggingEnabled": true,
            "isLoopGuardEnabled": true,
            "portFastMode": "string",
            "isBpduFilterEnabled": true,
            "isBpduGuardEnabled": true,
            "isUplinkFastEnabled": true,
            "transmitHoldCount": 0,
            "uplinkFastMaxUpdateRate": 0,
            "stpInstances": {
              "configType": "string",
              "items": [
                {
                  "configType": "string",
                  "vlanId": 0,
                  "priority": 0,
                  "timers": {
                    "configType": "string",
                    "forwardDelay": 0,
                    "helloInterval": 0,
                    "maxAge": 0,
                    "isStpEnabled": true
                  }
                }
              ]
            }
          }
        ]
      },
      "stpInterfaceConfig": {
        "items": {
          "configType": "string",
          "interfaceName": "string",
          "guardMode": "string",
          "bpduFilter": "string",
          "bpduGuard": "string",
          "pathCost": 0,
          "portFastMode": "string",
          "priority": 0,
          "portVlanCostSettings": {
            "configType": "string",
            "items": [
              {
                "configType": "string",
                "cost": 0,
                "vlans": "string"
              }
            ]
          },
          "portVlanPrioritySettings": {
            "configType": "string",
            "items": [
              {
                "configType": "string",
                "priority": 0,
                "vlans": "string"
              }
            ]
          }
        }
      },
      "trunkInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "isProtected": true,
            "isDtpNegotiationEnabled": true,
            "pruneEligibleVlans": "string"
          }
        ]
      },
      "vtpGlobalConfig": {
        "items": [
          {
            "configType": "string",
            "mode": "string",
            "version": "string",
            "domainName": "string",
            "isPruningEnabled": true,
            "configurationFileName": "string",
            "sourceInterface": "string"
          }
        ]
      },
      "vtpInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "isVtpEnabled": true
          }
        ]
      },
      "vlanConfig": {
        "items": [
          {
            "configType": "string",
            "vlanId": 0,
            "name": "string",
            "isVlanEnabled": true
          }
        ]
      },
      "portChannelConfig": {
        "items": [
          {
            "configType": "string",
            "isAutoEnabled": true,
            "loadBalancingMethod": "string",
            "lacpSystemPriority": 0,
            "portchannels": {
              "configType": "string",
              "items": [
                {
                  "AnyOf": {
                    "EtherchannelConfig": {
                      "configType": "string",
                      "name": "string",
                      "minLinks": 0,
                      "memberPorts": {
                        "configType": "string",
                        "items": [
                          {
                            "configType": "string",
                            "interfaceName": "string",
                            "mode": "string"
                          }
                        ]
                      }
                    },
                    "LacpPortchannelConfig": {
                      "configType": "string",
                      "name": "string",
                      "minLinks": 0,
                      "memberPorts": {
                        "configType": "string",
                        "items": [
                          {
                            "configType": "string",
                            "interfaceName": "string",
                            "mode": "string",
                            "portPriority": 0,
                            "rate": 0
                          }
                        ]
                      }
                    },
                    "PagpPortchannelConfig": {
                      "configType": "string",
                      "name": "string",
                      "minLinks": 0,
                      "memberPorts": {
                        "configType": "string",
                        "items": [
                          {
                            "configType": "string",
                            "interfaceName": "string",
                            "mode": "string",
                            "portPriority": 0,
                            "learnMethod": "string"
                          }
                        ]
                      }
                    }
                  }
                }
              ]
            }
          }
        ]
      },
      "switchportInterfaceConfig": {
        "items": [
          {
            "configType": "string",
            "interfaceName": "string",
            "description": "string",
            "mode": "string",
            "accessVlan": 0,
            "voiceVlan": 0,
            "adminStatus": "string",
            "trunkAllowedVlans": "string",
            "nativeVlan": 0
          }
        ]
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: business_sda_hostonboarding_ssid_ippool
short_description: Resource module for Business Sda Hostonboarding Ssid Ippool
description:
  - Manage operations create and update of the resource Business Sda Hostonboarding Ssid Ippool.
  - Add SSID to IP Pool Mapping.
  - Update SSID to IP Pool Mapping.
version_added: '4.0.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  scalableGroupName:
    description: Scalable Group Name.
    type: str
  siteNameHierarchy:
    description: Site Name Hierarchy.
    type: str
  ssidNames:
    description: List of SSIDs.
    elements: str
    type: list
  vlanName:
    description: VLAN Name.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Fabric Wireless AddSSIDToIPPoolMapping
    description: Complete reference of the AddSSIDToIPPoolMapping API.
    link: https://developer.cisco.com/docs/dna-center/#!add-ssid-to-ip-pool-mapping
  - name: Cisco DNA Center documentation for Fabric Wireless UpdateSSIDToIPPoolMapping
    description: Complete reference of the UpdateSSIDToIPPoolMapping API.
    link: https://developer.cisco.com/docs/dna-center/#!update-ssid-to-ip-pool-mapping
notes:
  - SDK Method used are
    fabric_wireless.FabricWireless.add_ssid_to_ip_pool_mapping,
    fabric_wireless.FabricWireless.update_ssid_to_ip_pool_mapping,
  - Paths used are
    post /dna/intent/api/v1/business/sda/hostonboarding/ssid-ippool,
    put /dna/intent/api/v1/business/sda/hostonboarding/ssid-ippool,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.business_sda_hostonboarding_ssid_ippool:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    scalableGroupName: string
    siteNameHierarchy: string
    ssidNames:
      - string
    vlanName: string
- name: Update all
  cisco.dnac.business_sda_hostonboarding_ssid_ippool:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    scalableGroupName: string
    siteNameHierarchy: string
    ssidNames:
      - string
    vlanName: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "executionId": "string",
      "executionStatusUrl": "string",
      "message": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: download_software_release_create
short_description: Resource module for Download Software Release Create
description:
  - Manage operation create of the resource Download Software Release Create.
  - This api is used to trigger download workflow of a specific release.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  optionalPackages:
    description: Provide the list of optional package's id to be downloaded.Obtain the `id` from the `packagesn.id` attribute
      where `packagesn.optional` is true from the `/dna/system/api/v1/releases/releaseSummary` API where the `releaseName`
      and `releaseVersion` is the requested download version.
    elements: str
    type: list
  releaseName:
    description: The `releaseName` of the release to be downloaded.Obtain the releaseName from the `name` attribute in the
      response of the `/dna/system/api/v1/releases` API.
    type: str
  releaseVersion:
    description: The `releaseVersion` of the release to be downloaded.Obtain the releaseVersion from the `version` attribute
      in the response of the `/dna/system/api/v1/releases` API.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for System Software Upgrade DownloadRelease
    description: Complete reference of the DownloadRelease API.
    link: https://developer.cisco.com/docs/dna-center/#!download-release
notes:
  - SDK Method used are
    system_software_upgrade.SystemSoftwareUpgrade.download_release,
  - Paths used are
    post /dna/system/api/v1/downloadSoftwareRelease,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.download_software_release_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    optionalPackages:
      - string
    releaseName: string
    releaseVersion: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_controllers_network_device_id_provision_status_info
short_description: Information module for Wireless Controllers Network Device Id Provision Status
description:
  - Get all Wireless Controllers Network Device Id Provision Status.
  - Retrieves wireless controller's provision status.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - >
        NetworkDeviceId path parameter. Obtain the networkDeviceId value by using the API call GET
        /dna/intent/api/v1/network-device/ip-address/${ipAddress}.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless WirelessControllerProvisionStatus
    description: Complete reference of the WirelessControllerProvisionStatus API.
    link: https://developer.cisco.com/docs/dna-center/#!wireless-controller-provision-status
notes:
  - SDK Method used are
    wireless.Wireless.wireless_controller_provision_status,
  - Paths used are
    get /dna/intent/api/v1/wirelessControllers/{networkDeviceId}/provisionStatus,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Controllers Network Device Id Provision Status
  cisco.dnac.wireless_controllers_network_device_id_provision_status_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "networkDeviceId": "string",
        "deviceName": "string",
        "siteId": "string",
        "siteNameHierarchy": "string",
        "networkIntentProvisionStatus": "string",
        "modelConfigProvisionStatus": "string",
        "lastProvisionedTimeStamp": "string",
        "outOfSync": true
      },
      "version": "string"
    }
"""
